==> mapme.biodiversity_0.0.1.tar.gz: mapme.biodiversity/R/get_greenhouse.R <==
#' Forest greenhouse gas emissions
#'
#' This resource is part of the publication by Harris et al. (2021)
#' "Global maps of twenty-first century forest carbon fluxes.". It
#' represents "the greenhouse gas
#' emissions arising from stand-replacing forest disturbances that occurred in
#' each modeled year (megagrams CO2 emissions/ha, between 2001 and 2020).
#' Emissions include all relevant ecosystem carbon pools (aboveground biomass,
#' belowground biomass, dead wood, litter, soil) and greenhouse gases (CO2, CH4,
#' N2O)." The area unit that is downloaded here corresponds to the
#' "megagrams of CO2 emissions/pixel" layer, in order to support the calculation
#' of area-wise emissions.
#'
#' There are no arguments users need to specify. However, users should note
#' that the spatial extent for this dataset does not totally cover the same
#' extent as the \code{treecover2000} and \code{lossyear} resources by Hansen
#' et al. (2013). A missing value (NA) will be inserted for greenhouse gas
#' emissions for areas where no data is available.
#'
#' @name greenhouse
#' @docType data
#' @keywords resource
#' @format A global tiled raster resource available for all land areas.
#' @references Harris, N.L., Gibbs, D.A., Baccini, A. et al. Global maps of
#' twenty-first century forest carbon fluxes. Nat. Clim. Chang. 11, 234–240
#' (2021). https://doi.org/10.1038/s41558-020-00976-6
#' @source \url{https://data.globalforestwatch.org/datasets/gfw::forest-greenhouse-gas-emissions/about}
NULL


#' Get greenhouse layer
#'
#' @param x An sf object returned by init_portfolio
#' @param verbose Logical controlling verbosity.
#' @param rundir A directory where intermediate files are written to.
#' @keywords internal
#' @noRd
.get_greenhouse <- function(x,
                            verbose = TRUE,
                            rundir = tempdir()) {
  bbox <- st_bbox(x)
  index_file <- system.file("extdata", "greenhouse_index.geosjon", package = "mapme.biodiversity")
  spatialindex <- st_read(index_file, quiet = TRUE)
  targets <- unlist(st_intersects(st_as_sfc(bbox), spatialindex))
  tileids <- spatialindex$tile_id[targets]
  urls <- as.character(
    spatialindex$Mg_CO2e_px_download[spatialindex$tile_id %in% tileids]
  )
  filenames <- file.path(
    rundir,
    sprintf("gfw_forest_carbon_gross_emissions_Mg_CO2e_px_%s.tif", tileids)
  )
  # TODO: Parallel downloads
  aria_bin <- attributes(x)$aria_bin
  if (is.null(attr(x, "testing"))) .download_or_skip(urls, filenames, verbose, check_existence = FALSE, aria_bin = aria_bin)
  # return all paths to the downloaded files
  filenames
}

==> mapme.biodiversity_0.1.2.tar.gz: mapme.biodiversity/R/get_greenhouse.R <==
#' Forest greenhouse gas emissions
#'
#' This resource is part of the publication by Harris et al. (2021)
#' "Global maps of twenty-first century forest carbon fluxes.". It
#' represents "the greenhouse gas
#' emissions arising from stand-replacing forest disturbances that occurred in
#' each modeled year (megagrams CO2 emissions/ha, between 2001 and 2020).
#' Emissions include all relevant ecosystem carbon pools (aboveground biomass,
#' belowground biomass, dead wood, litter, soil) and greenhouse gases (CO2, CH4,
#' N2O)." The area unit that is downloaded here corresponds to the
#' "megagrams of CO2 emissions/pixel" layer, in order to support the calculation
#' of area-wise emissions.
#'
#' There are no arguments users need to specify. However, users should note
#' that the spatial extent for this dataset does not totally cover the same
#' extent as the \code{treecover2000} and \code{lossyear} resources by Hansen
#' et al. (2013). A missing value (NA) will be inserted for greenhouse gas
#' emissions for areas where no data is available.
#'
#' @name greenhouse
#' @docType data
#' @keywords resource
#' @format A global tiled raster resource available for all land areas.
#' @references Harris, N.L., Gibbs, D.A., Baccini, A. et al. Global maps of
#' twenty-first century forest carbon fluxes. Nat. Clim. Chang. 11, 234–240
#' (2021). https://doi.org/10.1038/s41558-020-00976-6
#' @source \url{https://data.globalforestwatch.org/datasets/gfw::forest-greenhouse-gas-emissions/about}
NULL


#' Get greenhouse layer
#'
#' @param x An sf object returned by init_portfolio
#' @param verbose Logical controlling verbosity.
#' @param rundir A directory where intermediate files are written to.
#' @keywords internal
#' @noRd
.get_greenhouse <- function(x,
                            verbose = TRUE,
                            rundir = tempdir()) {
  bbox <- st_bbox(x)
  index_file <- system.file("extdata", "greenhouse_index.geosjon", package = "mapme.biodiversity")
  spatialindex <- st_read(index_file, quiet = TRUE)
  targets <- unlist(st_intersects(st_as_sfc(bbox), spatialindex))
  tileids <- spatialindex$tile_id[targets]
  urls <- as.character(
    spatialindex$Mg_CO2e_px_download[spatialindex$tile_id %in% tileids]
  )
  filenames <- file.path(
    rundir,
    sprintf("gfw_forest_carbon_gross_emissions_Mg_CO2e_px_%s.tif", tileids)
  )
  if (attr(x, "testing")) {
    return(basename(filenames))
  }
  aria_bin <- attributes(x)$aria_bin
  .download_or_skip(urls, filenames, verbose, check_existence = FALSE, aria_bin = aria_bin)
  # return all paths to the downloaded files
  filenames
}
